@@ -3,10 +3,13 @@
 import logging
 
 from ._standard_AAs import STANDARD_AA_DOC
+from ._rna_bases import RNA_DOC
+from ._dna_bases import DNA_DOC
+from ._compress import slimdown_cif
 from . import _pdbinf
 from ._pdbinf import (
     assign_pdb_bonds,
-    load_pdb_file,
+    load_pdb_file, load_pdbx_file,
 )
 
 logging.getLogger(__name__).addHandler(logging.NullHandler())
